.. _monte_carlo:

Random walk based dependency graph sampling
-------------------------------------------

This predictor implements sampling of a dependency graph based on `Random walk
method <https://en.wikipedia.org/wiki/Random_walk>`_. You can see this
method as a random rays into dependency graph that resolve final states (fully
pinned down software stacks).
